[social-network-analysis](https://github.com/itsDevhere/social-network-analysis)

Update v1.1 done at **16-05-2019 @ 01:30 pm**

# Social Network Analysis Loksabha '19 Election Prediction
Social Networking Analysis  is a technique to analyse a given dataset to extract useful information and understanding the trend.
We are currently working on analyzing tweets based party name  input,analyse and plot graph for better statistical understanding and prediction purposes.
Group project of RCCIIT (Session 2015-19),Department of CSE under mentorship of Mrs.Monika Singh.

This repository will hold and be updated all the undergoing changes so far the project has experienced till now and till then.

## Steps to Install
Install :   `pip install sna_prediction`

Run     :   `sna_prediction`

## What's done as of now

 - Added new Positive-Negative tweet per party graph
 -  Now, pie chart and wordcloud is displayed in same fig
 - Pie chart and wordcloud has both dpi of 200

## Known Issues:

 - K-Map slider selected less than 3 takes longer time to render the graph due to large dataset
 - Data being huge take some time to load.Please stay patient.
 
## Active Contribution

[Devpratim](https://github.com/itsDevhere "https://github.com/itsDevhere")

[Rana](https://github.com/RanaMondal03 "https://github.com/RanaMondal03")

[Souvik](https://github.com/Souvik08 "https://github.com/Souvik08")

Soumjit


## Snapshots:
[Program Output](https://imgur.com/a/fNTlOoS) 

[+ve and -ve tweets per party](https://imgur.com/a/HUji90k)